function ncd_con

% NCD_CON Show the help for the functions in this toolbox.

% This file is automatically generated.  Matthew Simoneau, 09-04-98
% Copyright (c) 1984-98 by The MathWorks, Inc. All Rights Reserved
% $Revision: 1.11 $ $Date: 1998/10/16 23:19:27 $

helpwin('ncd_con/Contents');

function Contents
%MATLAB Tour Partial Function Help:  ncd_con
%
%Double click on any function for more information
%
%  Nonlinear Control Design Blockset
%  Version 1.1.3 (R11) 10-Aug-1998
% 
%  Dialog Box Managers.
%    coneddlg   - Manages a dialog box for the NCD Blockset Constraint editor.
%    paramdlg   - Manages a dialog box for NCD Blockset Optimization Parameters.
%    rangedlg   - Manages a dialog box for Axes Ranges.
%    refdlg     - Manages a dialog box for NCD Blockset Reference Signal.
%    stepdlg    - Manages a dialog box for NCD Step Response.
%    uncerdlg   - Manages a dialog box for NCD Blockset Uncertain Variables.
% 
%  Main interface.
%    contrncd   - Creates the uicontrols for the NCD Blockset constraint figure.
%    menuncd    - Creates the uimenus for the NCD Blockset constraint figure.
%    ncdblock   - SIMULINK system containing the NCD block.
%    rmsblock   - SIMULINK system with continuous and discrete RMS value blocks.
%    slblocks   - Defines the block library for NCD Blockset.
%    optblock   - Script which opens an NCD Blockset figure.
%    optfig     - Creates an NCD Blockset constraint figure.
% 
%  Main optimization.
%    initresp   - Plots the initial response of the Simulink Model.
%    costfun    - Cost function for NCD Blockset optimization.
%    gradfun    - Gradient of the Cost function for NCD Blockset optimization.
%    nlinopt    - Runs the optimization algorithm.
%    copymdl    - Creates an augmented SL model, used in gradient finding.
%    tvarset    - S-function to set the tunable parameters.
% 
%  Demonstrations.
%    ncddemo    - SIMULINK system containing all NCD Blockset demos.
%    ncddemo1   - PID Controller.
%    ncddemo2   - LQR with Feedforward Controller.
%    ncddemo3   - MIMO PI Controller.
%    ncddemo4   - Inverted Pendulum.
%    rmsdemo    - SIMULINK system demo for using the RMS blocks.
% 
%  Tutorials.
%    ncdtut1    - Control Design Example.
%    ncdtut2    - System Identification Example.
%    ncdtut2old - Old System Identification Example.
% 
%  Demonstration and Tutorial Utilities.
%    ncd1init   - Setup for optimization of ncddemo1.
%    ncd2init   - Setup for optimization of ncddemo2.
%    ncd3init   - Setup for optimization of ncddemo3.
%    ncd4init   - Setup for optimization of ncddemo4.
%    penddata   - Setup for ncdtut2.
%    ncdtut2old.mat - Data for ncdtut2old.
% 
%  Interface Utilities.
%    bdncd      - NCD Blockset WindowButtonDownFcn.
%    bmncd      - NCD Blockset WindowButtonMotionFcn
%    buncd      - NCD Blockset WindowButtonUpFcn.
%    curobj     - Provides information about what is under CurrentPoint.
%    dividecb   - Divides constraint bounds in two.
%    delline    - Deletes all plots from the NCD figure.
%    donep      - Callback for the Close pushbutton and menu.
%    errorncd   - Manages commonly generated NCD errors.  Calls errordlg.
%    fillaxes   - Creates the constraint bounds and does some data checking.
%    keyncd     - NCD Blockset KeyPressFcn.
%    loado      - Loads and displays NCD Blockset data.
%    makesurf   - Creates and constraint bound surface and patch.
%    snapncd    - Snaps constraint bar in 22.5 degree increments.
%    refresho   - Makes the constraint matrix consistent with figure.
%    saveload   - True if file is selected from SELECTFILE.
%    texted     - Callback for Port editable text.
%    undoncd    - Undoes the last NCD Blockset GUI operation.
%    updatdlg   - Updates the NCD dialog boxes.
% 
%  Optimization Utilities.
%    convertm   - Converts constraint matrix into optimization format.
%    minipars   - Miniparser for the NCD Blockset.
%    montevar   - Initializes Monte Carlo simulations.
%    ncdglob    - Defines NCD global variables.
%    str2mat2   - Converts one row string into multi-row string.
% 
%  Help text files (.hlp extension)
%    ncdhelp    - Driver to pop up the NCD Blockset Help windows.
%    hotkey     - Hot-key help
%    mainncd    - General NCD help
%    paramdlg   - Help on Optimization Parameters dialog box
%    readncd    - Contains same info as Readme.m
%    stepdlg    - Help on Step Response dialog box
%    uncerdlg   - Help on Uncertain Variables dialog box
%

function coneddlg
%MATLAB Tour Partial Function Help:  ncd_con
%
% CONEDDLG Manages a dialog box for the NCD Blockset Constraint editor.
% 
%        CONEDDLG(FLAG) generates  a dialog box when called 
%        with an argument of zero and manages the callbacks
%        of the  uicontrols in the dialog box.  Each of the 
%        uicontrols calls this function with a different flag.  
%        Changes to the constraint are made as soon  as the
%        cursor leaves the associated editable control area.
% 
%        0  Menu selection creates Constraint Editor dialog box.
%        1  Limiting constraint radio callback
%        2  Overachieving constraint radio callback
%        3  Weight editable text callback
%        4  Clear Type pushbutton calback
%        5  Position editable text callback

function paramdlg
%MATLAB Tour Partial Function Help:  ncd_con
%
% PARAMDLG Manages a dialog box for NCD Blockset Optimization Parameters.
% 
%        PARAMDLG(FLAG) generates a dialog box when called with an
%        argument of zero and manages the callbacks of the uicontrols
%        in the dialog box. Each of the uicontrols calls this function
%        with a different flag. Changes to the Optimization Parameters
%        are made as soon as the cursor leaves he associated editable
%        control area, and the Revert function is possible because the
%        Parameters are stored in the UserData of the editable text.
% 
%        0 Menu selection creates Optimization Parameter dialog box.
%        1 ncdStruct.Tdelta editable text callback
%        2 ncdStruct.TvarStr editable text callback
%        3 ncdStruct.OptmOptns(1) Check Box callback
%        4 ncdStruct.OptmOptns(2) editable text callback
%        5 ncdStruct.OptmOptns(3) editable text callback
%        6 ncdStruct.TvlbStr editable text callback 
%        7 ncdStruct.TvubStr editable text callback
%        8 Reset flag
%        9 Revert pushbutton callback
%        10 ncdStruct.CostFlag Check Box callback
%        11 ncdStruct.GradFlag Check Box callback

function rangedlg
%MATLAB Tour Partial Function Help:  ncd_con
%
% RANGEDLG Manages a dialog box for Axes Ranges.
% 
%        RANGESDLG(FLAG) generates a dialog box when called 
%        with an argument of zero and manages the callbacks
%        of the uicontrols in the dialog box. Each of the 
%        uicontrols calls this function with a different flag.  
% 
%        0  Menu selection creates Axes Ranges dialog box.
%        1  XLim (Time) editable text callback
%        2  YLim vector editable text callback
%        3  XLabel (Time) editable text callback
%        4  YLabel editable text callback

function refdlg
%MATLAB Tour Partial Function Help:  ncd_con
%
% REFDLG Manages a dialog box for NCD Blockset Reference Signal.
% 
%        REFDLG(FLAG) generates a dialog box when called with an
%        argument of zero and manages the callbacks of the uicontrols
%        in the dialog box.  Each of the uicontrols calls this
%        function with a different flag.  
% 
%        0  Menu selection creates Reference Signal dialog box.
%        1  Time vector editable text callback
%        2  Input vector editable text callback
%        3  Plot pushbutton callback (executed in the base workspace)
%        4  Revert pushbutton callback
%        5  Reset flag

function stepdlg
%MATLAB Tour Partial Function Help:  ncd_con
%
% STEPDLG Manages a dialog box for NCD Step Response.
% 
%        STEPDLG(FLAG) generates a dialog box when called
%        with an argument of zero and manages the callbacks
%        of the uicontrols in the dialog box.  Each of the
%        uicontrols calls this function with a different flag. 
% 
%        0  Menu selection creates Step Response dialog box.
%        1  Settling time editable control callback
%        2  Rise time editable control callback
%        3  Percent settling editable control callback
%        4  Percent rise editable control callback
%        5  Overshoot editable control callback
%        6  Undershoot editable control callback
%        7  Step time editable control callback
%        8  Final time editable control callback
%        9  Initial output editable control callback
%       10  Final output editable control callback
%       11  Revert pushbutton callback

function uncerdlg
%MATLAB Tour Partial Function Help:  ncd_con
%
%  UNCERDLG Manages a dialog box for NCD Blockset Uncertain Variables.
% 
%        UNCERDLG(FLAG) generates a dialog box when called 
%        with an argument of zero and manages the callbacks
%        of the uicontrols in the dialog box.  Each of the uicontrols 
%        calls this function with a different flag.  Changes to the 
%        Uncertain Variables are made as soon as the cursor leaves 
%        the associated editable control area, and the Revert function
%        is possible because the Variables are stored in the UserData 
%        of the editable text.
% 
%        0  Menu selection creates Optimization Parameter dialog box.
%        1  ncdStruct.UvarStr editable text callback
%        2  ncdStruct.UvlbStr editable text callback
%        3  ncdStruct.UvubStr editable text callback
%        4  ncdStruct.NumMC editable text callback
%        5  Constrain nominal simulation radio button callback
%        6  Constrain Lower bound simulation radio button callback
%        7  Constrain Upper bound simulation radio button callback
%        8  Constrain Monte Carlo simulations radio button callback
%        9  Reset flag
%       10  Revert pushbutton callback
%       11  Help pushbutton callback

function contrncd
%MATLAB Tour Partial Function Help:  ncd_con
%
% CONTRNCD creates the uicontrols for the NCD Blockset constraint figure.
% 
%        CONTRNCD(FIG,SYS,CB,OUT) is called by optfig.m.
%        CB is the current system block and OUT is the
%        current system output.
% 
%        

function menuncd
%MATLAB Tour Partial Function Help:  ncd_con
%
% MENUNCD creates the uimenus for the NCD Blockset constraint figure.
% 
%        MENUNCD(FIG,SYS) is called by optfig.m.
% 
%        

function ncdblock
%MATLAB Tour Partial Function Help:  ncd_con
%
%ncdblock is a Simulink model

function slblocks
%MATLAB Tour Partial Function Help:  ncd_con
%
% SLBLOCKS Defines the block library for a specific Toolbox or Blockset.

function optblock
%MATLAB Tour Partial Function Help:  ncd_con
%
% OPTBLOCK Script which opens NCD Blockset figure.
% 
%        OPTBLOCK is called by double-clicking on 
%        the masked NCD Blockset Optimization outport.
% 
%        

function optfig
%MATLAB Tour Partial Function Help:  ncd_con
%
% OPTFIG creates an NCD Blockset constraint figure.
% 
%        OPTFIG executes when the NCD Blockset masked
%        outport block is double clicked. If the
%        constraint figure for the outport block is
%        already displayed on the screen, it is
%        brought to the front.
% 
%        

function initresp
%MATLAB Tour Partial Function Help:  ncd_con
%
% INITRESP Plots the initial response for the NCD Blockset.
% 
%        

function costfun
%MATLAB Tour Partial Function Help:  ncd_con
%
% COSTFUN Cost function for NCD Blockset optimization.
% 
%        [CostFunction,ConstraintError] = COSTFUN(TVARVEC, ...
%             VARMTX,TVAREXT,SYSNAME,TIMEPTS,MU,ML,OFFSET, ...
%             SIMS,UVARMTX,UVAREXT,UVDATA,SIMOPTIONS)
%        calculates the CostFunction and ConstraintError given:
% 
%        Inputs:
%           TVARVEC    -- vectorized tunable parameters at this iteration
%           DTUNEVAR   -- suggested perturbations to the tunable parameters
%           SYSNAME    -- SIMULINK system name
%           TVARMTX    -- tunable parameter names formatted as a padded string matrix
%           TVAREXT    -- vector of (vevtorized) tunable parameter dimensions
%           TIMEPTS    -- time vector: [tstart:tdelta:tfinal]
%           MU         -- [<vectorized output index> <upper constraint> <weight>]
%           ML         -- [<vectorized output index> <lower constraint> <weight>]
%           OFFSET     -- NumOutPorts * length(TIMEPTS)
%           SIMS       -- vector of simulations to be constrained
%           UVARMTX    -- uncertain parameter names formatted as a padded string matrx
%           UVAREXT    -- vector of (vevtorized) tunable parameter dimensions
%           UVDATA     -- matrix of uncertain parameter values in each simulation
%           SIMOPTIONS -- simulation options
% 
%        

function gradfun
%MATLAB Tour Partial Function Help:  ncd_con
%
% GRADFUN Gradient of the Cost function for NCD Blockset optimization.
% 
%        [GradCostFcn,GradCnstrtErr,OPTIONS] = GRADFUN(TVARVEC,DTUNEVAR, ...
%                 GNEW,OPTIONS,TVARMTX,TVAREXT,SYSNAME,TIMEPTS,MU,ML,OFFSET, ...
%                         SIMS,UVARMTX,UVAREXT,UVDATA,SIMOPTIONS)
% 
%        Outputs:
%           GradCostFcn    -- gradient of the cost function
%           GradCnstrtErr  -- gradient of the Constraint Error
%           OPTIONS        -- vector of optimization OPTIONS
%  
%        Inputs:
%           TVARVEC   -- vectorized tunable parameters at this iteration
%           GNEW      -- gradient of the Lagrangian function 
%           OPTIONS   -- vector of optimization OPTIONS
%           SYSNAME   -- SIMULINK system name
%           TVARMTX   -- tunable parameter names formatted as a padded string matrix
%           TVAREXT   -- vector of (vevtorized) tunable parameter dimensions
%           TIMEPTS   -- time vector: [tstart:tdelta:tfinal]
%           MU        -- [<vectorized output index> <upper constraint> <weight>]
%           ML        -- [<vectorized output index> <lower constraint> <weight>]
%           OFFSET    -- NumOutPorts * length(TIMEPTS)
%           SIMS      -- vector of simulations to be constrained
%           UVARMTX   -- uncertain parameter names formatted as a padded string matrx
%           UVAREXT   -- vector of (vectorized) tunable parameter dimensions
%           UVDATA    -- matrix of uncertain parameter values in each simulation
%           SIMOPTIONS -- simulation options
% 
%        

function nlinopt
%MATLAB Tour Partial Function Help:  ncd_con
%
% NLINOPT Runs the optimization algorithm.
% 
%        NLINOPT(SYS,InitFlag) is called when the Start button is 
%        pushed or when the Initial response menu item is selected. 
%        It calls another routine to initialize any Monte Carlo
%        simulations.  It calls a routine to convert ncdStruct.CnstrLB and
%        ncdStruct.CnstrUB into constraints used by the optimization routine.
%        Finally, if InitFlag=1, it plots the initial response,
%        otherwise it calls the optimization routine.
% 
%        

function copymdl
%MATLAB Tour Partial Function Help:  ncd_con
%
% COPYMDL creates an augmented SL model, used in gradient finding.

function tvarset
%MATLAB Tour Partial Function Help:  ncd_con
%
%  S-Function to set the tunable parameters.

function ncddemo
%MATLAB Tour Partial Function Help:  ncd_con
%
%ncddemo is a Simulink model

function ncddemo1
%MATLAB Tour Partial Function Help:  ncd_con
%
%ncddemo1 is a Simulink model

function ncddemo2
%MATLAB Tour Partial Function Help:  ncd_con
%
%ncddemo2 is a Simulink model

function ncddemo3
%MATLAB Tour Partial Function Help:  ncd_con
%
%ncddemo3 is a Simulink model

function ncddemo4
%MATLAB Tour Partial Function Help:  ncd_con
%
%ncddemo4 is a Simulink model

function rmsdemo
%MATLAB Tour Partial Function Help:  ncd_con
%
%rmsdemo is a Simulink model

function ncdtut1
%MATLAB Tour Partial Function Help:  ncd_con
%
%ncdtut1 is a Simulink model

function ncdtut2
%MATLAB Tour Partial Function Help:  ncd_con
%
%ncdtut2 is a Simulink model

function ncdtut2old
%MATLAB Tour Partial Function Help:  ncd_con
%
%ncdtut2old is a Simulink model

function ncd1init
%MATLAB Tour Partial Function Help:  ncd_con
%
% NCD1INIT Sets up necessary data files for optimization of ncddemo1.

function ncd2init
%MATLAB Tour Partial Function Help:  ncd_con
%
% NCD2INIT Sets up necessary data files for optimization of ncddemo2.

function ncd3init
%MATLAB Tour Partial Function Help:  ncd_con
%
% NCD3INIT Sets up necessary data files for optimization of ncddemo2.

function ncd4init
%MATLAB Tour Partial Function Help:  ncd_con
%
% NCD4INIT Setup for optimization of ncddemo4.

function penddata
%MATLAB Tour Partial Function Help:  ncd_con
%
% PENDDATA Script which initializes ncdtut2.

function bdncd
%MATLAB Tour Partial Function Help:  ncd_con
%
% BDNCD is the NCD Blockset WindowButtonDownFcn.

function bmncd
%MATLAB Tour Partial Function Help:  ncd_con
%
% BMNCD is the NCD Blockset WindowButtonMotionFcn

function buncd
%MATLAB Tour Partial Function Help:  ncd_con
%
% BUNCD is the NCD Blockset WindowButtonUpFcn.

function curobj
%MATLAB Tour Partial Function Help:  ncd_con
%
% CUROBJ provides information about what is under CurrentPoint
%        [SURFS,SEGMENT,MMODE,OLDPT] = CUROBJ returns the SURFace, 
%        SEGMENT, and Motion MODE of the constraint bound under 
%        CurrentPoint. SURFS=7 for the lower constraint; SURFS=8 for 
%        the upper constraint; else SURFS=0.
%        
%        MMODE Type of motion
%        -1    No motion (not clicked on surface or wrong SelectionType)
%         0    Open segment
%         1    Move segment in up/down mode (clicked in middle)
%         2    Move right side of segment (clicked at right edge)
%         3    Move left side of segment (clicked at left edge)
%         4    Move segment in left/right mode (clicked vertical face)
%        
%        CUROBJ also correctly selects and deselects segments.

function dividecb
%MATLAB Tour Partial Function Help:  ncd_con
%
% DIVIDECB Divides a bound into two parts.
% 
%        [LEFTSIDE,RIGHTSIDE] = DIVIDECB(BOUND,TIME) BOUND
%        into 2 bounds. LEFTSIDE contains all bounds less
%        than TIME and RIGHTSIDE contains all bounds greater
%        than TIME.
% 
%        

function delline
%MATLAB Tour Partial Function Help:  ncd_con
%
% DELLINE Deletes all plots from the NCD figure.

function donep
%MATLAB Tour Partial Function Help:  ncd_con
%
% DONEP is the callback for the Close pushbutton and menu.
% 
%        DONEP closes the current NCD Blockset constraint figure.
%        If any constraints, optimization parameters, or uncertain 
%        variables have changed since the last save, the user is
%        prompted to save the NCD Blockset data to a .mat file.

function fillaxes
%MATLAB Tour Partial Function Help:  ncd_con
%
% FILLAXES creates the constraint bounds and does some data checking.
% 
%        S_and_P = FILLAXES(FIG,AXS) creates the upper and lower constraint
%        bounds and patches in the constraint figure FIG. It also does some
%        error checking on the matrices ncdStruct.CnstrLB and ncdStruct.CnstrUB.
% 
%        The output S_and_P contains the handles of the bounds and patches.
% 
%        

function keyncd
%MATLAB Tour Partial Function Help:  ncd_con
%
% KEYNCD is the NCD Blockset KeyPressFcn.
% 
%        KEYNCD(CHAR) operates according to CHAR (or
%        the CurrentCharacter if no input is suppied).
%        The keys u,d,l,r,q,z,p,m will move or stretch the selected
%        segment by about two percent of the axis limits while 
%        U,D,L,R,Q,Z,P,M will move or stretch the selected segment
%        by about 20 percent of the axis limits.  F,f,B,b toggle
%        forward and backward through the constraint bounds.

function loado
%MATLAB Tour Partial Function Help:  ncd_con
%
% LOADO Loads and displays NCD Blockset data.
% 
%        LOADO loads and displays NCD Blockset data and evaluates
%        a string in the base workspace to plot the Reference Signal.
% 
%        

function makesurf
%MATLAB Tour Partial Function Help:  ncd_con
%
% MAKESURF creates and constraint bound surface and patch.
% 
%        [SURFH,PATCHH] = MAKESURF(FIG,AXS,BOUND,FLAG) creates the
%        surface with handle SURFH and patch with handle PATCHH
%        given the constraint bound matrix BOUND composed of
%        [xdata; ydata; s_ud; cdata].  The fourth row is optional.
%        FLAG=1 is a lower bound constraint; FLAG=2 is an upper
%        bound constraint.  The surface and patch are created in
%        the figure FIG.

function snapncd
%MATLAB Tour Partial Function Help:  ncd_con
%
% SNAPNCD Snaps constraint bar in 22.5 degree increments.
% 
%        NEWYLR = SNAPNCD(XLL,<YLL>,<XLR>,<YLR>) snaps YLR so that
%        the constraint bar will be at angle with the horizontal 
%        which is a multiple of 22.5 degrees (pi/8 rad).
%        Function can also take a single (nx4) input argument.

function refresho
%MATLAB Tour Partial Function Help:  ncd_con
%
% REFRESHO makes the constraint matrices consistent with figure.
% 
%        REFRESHO(FIG,FLAG) makes the constraint bound matrices (ncdStruct.CnstrLB
%        and ncdStruct.CnstrUB) and the figure constraints consistent by changing
%        the constraint matrices.  FLAG=1 means only refresh the lower constraint,
%        FLAG=2 means only refresh the upper constraint, and FLAG=[1 2] means
%        refresh both. With no arguments, both constraints of the CurrentFigure
%        are refreshed.
% 
%        REFRESHO also redraws the constraint bounds and associated patches by
%        calling MAKESURF.
%  
% 
%        

function saveload
%MATLAB Tour Partial Function Help:  ncd_con
%
% SAVELOAD True if NCD filing operation performed sucessfully.
% 
%        OK = SAVELOAD(SYS,FLAG) pulls up a UIGETFILE dialog
%        box if FLAG=0 and tries to load data. If FLAG=1, it 
%        pulls up UIPUTFILE and tries to save data. If FLAG=2,
%        it saves immediately to SYS.MAT.
% 
%        

function texted
%MATLAB Tour Partial Function Help:  ncd_con
%
% TEXTED Callback for Port editable text.
%        TEXTED changes the port number on the masked
% 		SIMULINK outport and also its 'Mask Display'.

function undoncd
%MATLAB Tour Partial Function Help:  ncd_con
%
% UNDONCD undoes the last NCD Blockset GUI operation.
% 
%        UNDONCD undoes the last command.  The logic is simple.
%        Any time the constraint bounds are changed, the old
%        constraint bounds are made invisible and are placed 
%        in the undo buffer. If the undo buffer is not empty, 
%        undo'ing will install the constraints in the undo buffer 
%        and put the present constraints into the undo buffer.  
%        Thus undo'ing twice will return the constraints to 
%        their original condition.
% 
%        Note, certain operations may reset the undo buffer (to zero).

function updatdlg
%MATLAB Tour Partial Function Help:  ncd_con
%
%  UPDATDLG updates the NCD dialog boxes.
% 
%        UPDATDLG(FLAG) updates the appropriate NCD dialogs.

function convertm
%MATLAB Tour Partial Function Help:  ncd_con
%
% CONVERTM converts constraint matrix into optimization format.
% 
%        M = CONVERTM(BOUND,TIMEPOINTS) takes the constraint matrix BOUND,
%        the simulation start time TIMEPOINTS(1), simulation stop time
%        TIMEPOINTS(END), the intermediate time points TIMEPOINTS(2:end-1)
%        and converts to a vector of constraints M, which are to be passed
%        to the optimization routine.

function minipars
%MATLAB Tour Partial Function Help:  ncd_con
%
% MINIPARS is a miniparser for the NCD Blockset.
% 
%        [M,ERROR_STR] = MINIPARS(STR,FLAG) is a miniparser
%        for the NCD Blockset.
%        eg: 'abc de  f ghij' becomes [abc ]
%                                     [de  ]
%                                     [f   ]
%                                     [ghij]
%        Uses either spaces, commas, semi-colons, or brackets
%        as separators.  Thus 'a 10*[b c] d' will crash. User
%        must instead say 'a [10*[b c]] d'.

function montevar
%MATLAB Tour Partial Function Help:  ncd_con
%
% MONTEVAR Initializes Monte Carlo simulations.
% 
%        [SIMS,UVARMTX,UVAREXT,UVDATA] = MONTEVAR initializes the Monte Carlo
%        simulations and returns: a vector of simulations to  be constrained (SIMS),
%        a padded string matrix with names of the uncertain variables (UVARMTX),
%        a vector containing the lengths of the (vectorized) uncetrain variables,
%        and a matrix UVDATA containing the uncertain variable data, as:
%              UVDATA(:,1)     -- for nominal plant
%              UVDATA(:,2)     -- for lower bound plant
%              UVDATA(:,3)     -- for upper bound plant
%              UVDATA(:,4:end) -- for Monte Carlo constrianed plants
% 
%        

function ncdglob
%MATLAB Tour Partial Function Help:  ncd_con
%
%  NCDGLOB Script to declare NCD Blockset global variables.

function str2mat2
%MATLAB Tour Partial Function Help:  ncd_con
%
% STR2MAT2 converts one row string into multi-row string.
%        [M,ERROR_STR] = STR2MAT2(STR) takes a string with spaces 
%        and forms a matrix where the spaces start a new column.  
%        No column can contain only blank spaces. Also there are 
%        no blanks in the first column.
%        eg: 'abc de  f ghij' becomes [abc ]
%                                     [de  ]
%                                     [f   ]
%                                     [ghij]

function ncdhelp
%MATLAB Tour Partial Function Help:  ncd_con
%
%  NCDHELP is the driver function to invoke helpwin from the NCD Blockset.

